
(_api_geodetic)=
# Geodetic

## Specialized Instances
```{eval-rst}

.. autosummary::
    :toctree: generated/

    sasktran2.WGS84
    sasktran2.SphericalGeoid

```

## sk.Geodetic

```{eval-rst}
.. autosummary::
    :toctree: generated/

    sasktran2.Geodetic
```
